<template>
<div class="devTotalLineContainer">
  <div class="chartPart">
    <chart :optionIn="options" />
  </div>
<!--  <echarts chart-id="devTotalLine" :chart-option="options"></echarts>-->
</div>
</template>

<script>
import chart from "@/components/chart.vue";
export default {
  name: 'devTotalLine',
  components: {
    chart
  },
  props: {
    selected: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      options: {
        grid: {
          top: "10%",
          left: '10%',
          right: '0',
          bottom: "20%"
        },
        tooltip: {
          trigger: "axis",
          axisPointer: {
            type: "shadow",
            label: {
              show: true
            }
          }
        },
        xAxis: {
          boundaryGap: false,
          data: [
            "00:00",
            "02:00",
            "04:00",
            "06:00",
            "08:00",
            "10:00",
            "12:00",
            "14:00",
          ],
          splitLine: {
            show: true,
            interval: 0,
            lineStyle: {
              color: 'rgba(250,250,250,0.2)',
              type: 'dashed'
            }
          },
          axisLine: {
            show: true, //隐藏X轴轴线
            lineStyle: {
              color: 'rgba(250,250,250,0.4)',
              width: 1
            }
          },
          axisTick: {
            show: false //隐藏X轴刻度
          },
          axisLabel: {
            show: true,
            interval: 1,
            textStyle: {
              color: "rgba(126,206,244,0.6)", //X轴文字颜色
              fontSize: 12
            }
          },
          splitArea: {
            show: false,
            interval: 0,
            areaStyle: {
              color: ["rgba(30, 47, 66, 0.5)", "rgba(250,250,250,0)"]
            }
          }
        },
        yAxis: {
          type: "value",
          splitLine: {
            show: true,
            lineStyle: {
              color: 'rgba(250,250,250,0.2)',
              type: 'dashed'
            }
          },
          splitNumber: 3,
          axisTick: {
            show: false
          },
          axisLine: {
            show: false
          },
          axisLabel: {
            show: true,
            textStyle: {
              color: "rgba(126,206,244,0.6)",
              fontSize: 12
            }
          },
        },
        series: [{
          name: "",
          type: "line",
          smooth: true, //平滑曲线显示
          showAllSymbol: true, //显示所有图形。
          symbol: "none", //标记的图形为实心圆
          lineStyle: {
            color: "rgba(255,170,5, .8)",
            width: 2
          },
          areaStyle: {
            color: new this.$echarts.graphic.LinearGradient(0, 0, 0, 1, [{
                offset: 0,
                color: "rgba(255,170,5, .8)"
              },
              {
                offset: 1,
                color: "rgba(255,170,5, 0)"
              }
            ])
          },
          data: []
        }]
      }
    }
  },
  watch: {
    selected(newV) {
      this.initChart(newV)
    }
  },
  mounted() {
    this.$nextTick(() => {
      this.initChart(this.selected)
    })
  },
  methods: {
    initChart(data) {
      let seriesData = []
      switch (data) {
        case 'thermal':
          seriesData = [1237, 1249, 1268, 1311, 1320, 1370, 1392, 1439, 1466, 1482, 1506, 1515]
          break;
        case 'waterSupply':
          seriesData = [4507, 4521, 4670, 4832, 5103, 5210, 5437, 5988, 6013, 6134, 6271, 6379]
          break;
        case 'gas':
          seriesData = [3462, 3864, 4210, 4633, 4722, 4764, 4910, 5019, 5214, 5349, 5394, 5437]
          break;
        case 'integrated':
          seriesData = [53, 32, 20, 61, 42, 65, 110, 30, 112, 70, 57, 38]
          break;
        case 'waterlogging':
          seriesData = [4106, 4206, 4320, 4437, 4520, 4673, 4721, 4755, 4867, 5017, 5134, 5297]
          break;
        case 'fire':
          seriesData = [3492, 3964, 4210, 4603, 4732, 4762, 4810, 5119, 5203, 5294, 5335, 5477]
          break;
        case 'pipeRack':
          seriesData = [6837, 7056, 7149, 7287, 7421, 7503, 7536, 7638, 7934, 8139, 8237, 8305]
          break;
        default:
          break;
      }
      this.options.series[0].data = [...seriesData]
    }
  }
}
</script>

<style lang="scss" scoped>
.devTotalLineContainer {
  //height: 100%;
  margin-top: 10px;
  min-height: 100px;
  width: 100%;

  .chartPart{
    width: 100%;
    height: 100px;
  }
}
</style>
